InstanceJsonModel class

Constructors

InstanceJsonModel({required String name, required bool isSingleton, required bool isLazy, required String inputType, required bool awaitInitialization, required int? initializationOrder, required bool isAsync, required bool isPart})
InstanceJsonModel.fromJson(Map json)
factory

Properties

awaitInitialization → bool
final
hashCode → int
The hash code for this object.
no setterinherited
initializationOrder → int?
final
inputType → String
final
isAsync → bool
final
isLazy → bool
final
isPart → bool
final
isSingleton → bool
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited